@@ -4,12 +4,12 @@ from .views import (
     login_and_get_tokens,
     logout,
     get_connection_token,
-    private_channel_subscription,
+    channels_subscription,
 )
 
 urlpatterns = [
     path("login/", login_and_get_tokens, name="instant-login"),
     path("logout/", logout, name="instant-logout"),
     path("get_token/", get_connection_token, name="instant-get-token"),
-    path("subscribe/", private_channel_subscription, name="instant-subscribe"),
+    path("subscribe/", channels_subscription, name="instant-subscribe"),
 ]
